# Audit

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**action** | **dict(str, object)** |  | [optional] 
**id** | **str** |  | [optional] 
**identifier** | **str** |  | [optional] 
**modified** | **datetime** |  | [optional] 
**object** | **str** |  | [optional] 
**sort_values** | **list[str]** |  | [optional] 
**type** | **str** |  | [optional] 
**user** | **str** |  | [optional] 
**version** | **int** |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


